Modules
- app
- baseline
- cli
- compliance
- CNSA 2.0 compliance annotations (issue #241).
- config
- diff
- engine
- fix
- git
- report
- rules
- secrets
- tui
Macros
- impl_
rule - Macro to reduce boilerplate in
impl Rule for …blocks.
Structs
Enums
Functions
- default_
confidence - Default confidence score for a finding when nothing else is specified.
Used by
Finding::confidencevia#[serde(default)]so baseline files written before the field existed still deserialize correctly.